package SPVM::HTTP::Tiny::Handle;

1;

=head1 Name

SPVM::HTTP::Tiny::Handle - Socket for HTTP

=head1 Description

The HTTP::Tiny::Handle class of L<SPVM> has methods to manipulate a socket handle for HTTP.

This class is a private class.

=head1 Copyright & License

Copyright (c) 2023 Yuki Kimoto

MIT License

